@@ -7,7 +7,7 @@ from aws_cdk import (
     aws_kms as _kms,
 )
 from aws_cdk.core import Tags
-from aws_cdk_constructs.utils import normalize_environment_parameter
+from aws_cdk_constructs.utils import normalize_environment_parameter, get_version
 
 engine_to_cdk_engine = {
     "legacy-aurora-mysql": _rds.DatabaseClusterEngine.aurora,
@@ -178,12 +178,23 @@ class Database(core.Construct):
         Tags.of(self).add("ApplicationName", app_name.lower().strip())
         Tags.of(self).add("Environment", environment)
 
+        # Apply FAO CDK tags
+        Tags.of(self).add("fao-cdk-construct", "database")
+        Tags.of(core.Stack.of(self)).add("fao-cdk-version", get_version())
+        Tags.of(core.Stack.of(self)).add("fao-cdk", "true")
+
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create conditions
 
         environment = environment.lower()
         aws_account = environments_parameters["accounts"][environment]
         account_id = aws_account["id"]
-        vpc = _ec2.Vpc.from_lookup(self, "VPC", vpc_id=aws_account["vpc"])
+        vpc = _ec2.Vpc.from_vpc_attributes (self, 
+            "VPC", 
+            vpc_id=aws_account["vpc"], 
+            public_subnet_ids=["subnet-8ccc3cea", "subnet-1b3ff853"], 
+            private_subnet_ids=["subnet-1bc5357d", "subnet-db37f093"],
+            availability_zones=["eu-west-1a", "eu-west-1b"]
+        )
 
         is_production = environment == "production"
         is_not_production = not is_production
