@@ -18,7 +18,7 @@ from aws_cdk.core import Tags
 import json
 import os
 import re
-from aws_cdk_constructs.utils import normalize_environment_parameter
+from aws_cdk_constructs.utils import normalize_environment_parameter, get_version
 
 alphanumericPattern = pattern = re.compile("\W")
 
@@ -730,6 +730,11 @@ class Microservice(core.Construct):
         Tags.of(self).add("ApplicationName", app_name, apply_to_launched_instances=True,)
         Tags.of(self).add("Environment", environment, apply_to_launched_instances=True,)
 
+        # Apply FAO CDK tags
+        Tags.of(self).add("fao-cdk-construct", "microservice")
+        Tags.of(core.Stack.of(self)).add("fao-cdk-version", get_version())
+        Tags.of(core.Stack.of(self)).add("fao-cdk", "true")
+
         self.id = id
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create conditions
@@ -875,7 +880,13 @@ class Microservice(core.Construct):
         # Important: you need an internet connection!
 
         # VPC
-        self._vpc = _ec2.Vpc.from_lookup(self, "VPC", vpc_id=aws_account["vpc"])
+        self._vpc = _ec2.Vpc.from_vpc_attributes (self, 
+            "VPC", 
+            vpc_id=aws_account["vpc"], 
+            public_subnet_ids=["subnet-8ccc3cea", "subnet-1b3ff853"], 
+            private_subnet_ids=["subnet-1bc5357d", "subnet-db37f093"],
+            availability_zones=["eu-west-1a", "eu-west-1b"]
+        )
 
         # ALB logs bucket
         self._alb_logs_bucket = _s3.Bucket.from_bucket_name(
