@@ -1,6 +1,6 @@
 from aws_cdk import core, aws_iam as _iam
 from aws_cdk.core import Tags
-from aws_cdk_constructs.utils import normalize_environment_parameter
+from aws_cdk_constructs.utils import normalize_environment_parameter, get_version
 
 class ServiceUserForIAC(core.Construct):
     """Construct to create the Service User to deploy a stack from a CD/CI pipeline
@@ -45,6 +45,11 @@ class ServiceUserForIAC(core.Construct):
         # Apply mandatory tags
         Tags.of(self).add("ApplicationName", app_name.lower().strip())
         Tags.of(self).add("Environment", environment)
+        
+        # Apply FAO CDK tags
+        Tags.of(self).add("fao-cdk-construct", "service_user_for_iac")
+        Tags.of(core.Stack.of(self)).add("fao-cdk-version", get_version())
+        Tags.of(core.Stack.of(self)).add("fao-cdk", "true")
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create conditions
 
